@@ -2,7 +2,9 @@ from .spacy_lang import SpacyLanguage
 from .sense2vec_lang import Sense2VecLanguage
 from .fasttext_lang import FasttextLanguage
 from .countvector_lang import CountVectorLanguage
-from .bpemblang import BytePairLang
+from .bpemblang import BytePairLanguage
+from .bpemblang import BytePairLanguage as BytePairLang
+from .convert_lang import ConveRTLanguage
 from .gensim_lang import GensimLanguage
 
 __all__ = [
@@ -11,5 +13,7 @@ __all__ = [
     "FasttextLanguage",
     "CountVectorLanguage",
     "BytePairLang",
+    "BytePairLanguage",
     "GensimLanguage",
+    "ConveRTLanguage",
 ]
