@@ -68,7 +68,7 @@ class SpacyLanguage(SklearnTransformerMixin):
         Important:
             The fasttext vectors are not given by this library.
             You can download the models [here](https://fasttext.cc/docs/en/crawl-vectors.html#models).
-            Note that these files are big that and loading this in can take a long time.
+            Note that these files are large and loading them can take a long time.
 
         Arguments:
             language: name of the language so that spaCy can grab correct tokenizer (example: "en" for english)
@@ -79,8 +79,8 @@ class SpacyLanguage(SklearnTransformerMixin):
         **Usage**:
 
         ```python
-        > lang = SpacyLanguage.from_texttext("nl", "/path/spacy/model", "~/Downloads/cc.nl.300.vec.gz")
-        > lang = SpacyLanguage.from_texttext("en", "/path/spacy/model", "~/Downloads/cc.en.300.vec.gz")
+        > lang = SpacyLanguage.from_fasttext("nl", "/path/spacy/model", "~/Downloads/cc.nl.300.vec.gz")
+        > lang = SpacyLanguage.from_fasttext("en", "/path/spacy/model", "~/Downloads/cc.en.300.vec.gz")
         ```
         """
         if not os.path.exists(output_dir):
@@ -97,9 +97,9 @@ class SpacyLanguage(SklearnTransformerMixin):
     @staticmethod
     def _input_str_legal(string):
         if sum(1 for c in string if c == "[") > 1:
-            raise ValueError("only one opener `[` allowed ")
+            raise ValueError("Only one opening bracket (`[`) is allowed")
         if sum(1 for c in string if c == "]") > 1:
-            raise ValueError("only one opener `]` allowed ")
+            raise ValueError("Only one closing bracket (`]`) is allowed")
 
     def __getitem__(self, query: Union[str, List[str]]):
         """
@@ -114,8 +114,8 @@ class SpacyLanguage(SklearnTransformerMixin):
         ```python
         > lang = SpacyLanguage("en_core_web_md")
         > lang['python']
-        > lang[['python'], ['snake']]
-        > lang[['nobody expects'], ['the spanish inquisition']]
+        > lang[['python', 'snake']]
+        > lang[['nobody expects', 'the spanish inquisition']]
         ```
         """
         if isinstance(query, str):
